/*
 * gc global variable provides access to GUI Composer infrastructure components and project information.
 * For more information, please see the Working with Javascript guide in the online help.
 */
var gc = gc || {};
gc.services = gc.services || {};


var client = null;
var server = "quickstart.messaging.internetofthings.ibmcloud.com";
var port = 443;

var defaultInterval = 10000;
var timer = null;
var bindings = {
  temp: null,
  location: null,
  interval: null
};

function resetUpdateInterval() {
    var interval = defaultInterval;
    if (bindings.interval) {
        interval = bindings.interval.getValue();
    }

    
    clearInterval(timer);
    timer = setInterval(publish, interval);
}

function onConnectSuccess() {
    resetUpdateInterval();
    publish();
}

function onConnectFailure() {
}

function onConnectionLost() {
    clearInterval(timer);
    connectServer();
}

function onMessage(topic, payload) {
}

function publish() {
    if (bindings.location) {
        var location = bindings.location.getValue();
        var topic = "iot-2/evt/demo/fmt/json";
        var payload = {
            d: {
                location: location,
                temperature: bindings.temp.getValue()
            }  
        };
        
        var message = new Messaging.Message(JSON.stringify(payload));
        message.destinationName = topic;
        if (client) {
            client.send(message);
        }
    }
}

function initServer() {
    try {
        var clientId = "d:quickstart:tidemotempserver:msp430g2tempdemo";
        
        client = new Messaging.Client(server, port, clientId);
        client.onMessageArrived = onMessage;
        client.onConnectionLost = onConnectionLost;
    } catch (err) {
        console.log("Error: " + err);
    }
}
 

function connectServer() {
    if (client) {
        client.connect({
           onSuccess: onConnectSuccess,
           onFailure: onConnectFailure,
           useSSL: true
        });
    }
}


/*
*  Boilerplate code for creating computed data bindings
*/
document.addEventListener('gc-databind-ready', function() 
{
    /* 
	*   Add custom computed value databindings here, using the following method:
	*
    *   function gc.databind.registry.bind(targetBinding, modelBinding, [getter], [setter]);
	*
	*   param targetBinding - single binding string or expression, or array of binding strings for multi-way binding.
	*   param modelBinding - single binding string or expression, or array of binding strings for multi-way binding.
	*   param getter - (optional) - custom getter function for computing the targetBinding value(s) based on modelBinding value(s).
	*   param setter - (optional) - custom setter function for computing the modelBinding value(s) based on targetBinding value(s).
    */
	
	// For example, a simple computed values based on simple expression
	// gc.databind.registry.bind('widget.id.propertyName', "targetVariable == 1 ? 'binding is one' : 'binding is not one'");
	
	bindings.temp = gc.databind.registry.getBinding('prop.temp');
	bindings.location = gc.databind.registry.getBinding('prop.location');
	bindings.interval = gc.databind.registry.getBinding('prop.interval');
	gc.databind.registry.getBinding('temp').addChangedListener({onValueChanged: function(oldValue, newValue) 
	    {
            bindings.temp.setValue(newValue);
	    }
	});
    
    gc.databind.registry.bind('prop.location', 'widget.ti_widget_providers.selectedValue');
    
    gc.databind.registry.bind('prop.interval', 'widget.ti_widget_interval.selectedValue',
        function(value)
        {
            return value;
        },
        function(value)
        {
            resetUpdateInterval();
            return value;
        }
    );
});

/*
*  Boilerplate code for creating custom actions
*/
document.addEventListener('gc-nav-ready', function() 
{
    /* 
	*   Add custom actions for menu items using the following api:
	*
    *   function gc.nav.registryAction(id, runable, [isAvailable], [isVisible]);
	*
	*   param id - uniquely identifies the action, and should correspond to the action property of the menuaction widget.
	*   param runable - function that performs the custom action.
	*   param isAvailable - (optional) - function called when the menu action is about to appear.  Return false to disable the action, or true to enable it.
	*   param isVisible - (optional) - function called when the menu action is about to appear.  Return false to hide the action, or true to make it visible.
    */
	
	// For example,
	// gc.nav.registerAction('myCustomCloseAction', function() { window.close(); }, function() { return true; }, function() { return true; });
	
	// Alternatively, to programmatically disable a menu action at any time use:
	// gc.nav.disableAction('myCustomCloseAction);    then enable it again using:  gc.nav.enableAction('myCustomCloseAction'); 
});

/*
*  Boilerplate code for working with components in the application gist
*/


var initComplete = false;
var templateObj;

// Wait for DOMContentLoaded event before trying to access the application template
var init = function() {
    templateObj = document.querySelector('#template_obj');

    // Wait for the template to fire a dom-change event to indicate that it has been 'stamped'
    // before trying to access components in the application.
	templateObj.addEventListener('dom-change',function(){
	    if (initComplete) return;
	    this.async(function(){
    	    initComplete = true;
    	    
    	    initServer();
    	    connectServer();
        },1);

	});
};

templateObj = document.querySelector('#template_obj');
if (templateObj) {
    init();
} else {
    document.addEventListener('DOMContentLoaded',init.bind(this))
}